
pacman::p_load(pacman, rio, devtools, survival, sqldf, lme4, survminer, psych, rcompanion, brms, htmltools, emmeans)
library(survival)
library(sqldf)
library(lme4)
library(survminer)
library(psych)
library(devtools)
library(rio)
library(rcompanion)
library(brms)
library(htmltools)
library(gmodels)
library(emmeans)



                               #RETRIEVE INITIAL DATASETS


    #Demography dataset has data for all individs in both communities, regardless of participation in Divorce interview.
    #This data is used to calculate community estimates for age of first marriage, birth, etc., as the Divorce interview
    #data does not include never-married individs, which would lead to inflated estimates. 

Demog <- read.csv ( file =#FILE DIRECTORY#)

    #Divorce dataset contains information from the Marriage and Divorce interview. 
Divorce <- read.csv ( file =#FILE DIRECTORY#)


                          
                          
                            #COMMUNITY ESTIMATES OF AGE AT FIRST MARRIAGE AND BIRTH

                          
     #Kaplan-Meier of First Marriage
FirstMarr12 <- subset(Demog,SampleMarrCommunity==1) #This includes all individuals >12 years old for whom age of 1st marriage is known
FirstMarrSurv <- survfit(Surv(MarrCensorAge, EverMarried) ~ sex, data = FirstMarr12)
summary(FirstMarrSurv)
ggsurvplot(FirstMarrSurv,
           pval = TRUE, conf.int = TRUE,
           risk.table = TRUE, # Add risk table
           risk.table.col = "strata", # Change risk table color by groups
           xlim = c(10,35),
           xlab="Age",
           ylab="Proportion Never-married",
           break.x.by = 5,
           linetype = "strata", # Change line type by groups
           surv.median.line = "hv", # Specify median survival
           ggtheme = theme_bw(), # Change ggplot2 theme
           palette = c("#E7B800", "#2E9FDF"))


     #Kaplan-Meier of First Birth
FirstBirth12 <- subset(Demog,SampleBirth==1) #This includes all individuals >12 years old for whom age of 1st birth is known
FirstBirthSurv <- survfit(Surv(BirthCensorAge, EverBirth) ~ sex, data = FirstBirth12)
summary(FirstBirthSurv)
ggsurvplot(FirstBirthSurv,
           pval = TRUE, conf.int = TRUE,
           risk.table = TRUE, # Add risk table
           risk.table.col = "strata", # Change risk table color by groups
           xlim = c(10,35),
           xlab="Age",
           ylab="Proportion Nulliparous",
           break.x.by = 5,
           linetype = "strata", # Change line type by groups
           surv.median.line = "hv", # Specify median survival
           ggtheme = theme_bw(), # Change ggplot2 theme
           palette = c("#E7B800", "#2E9FDF"))






                                       #DESCRIPTIVES OF DIVORCE INTERVIEW


     #Descriptives on participants
DIndivid <- subset(Divorce, Divorce$MarrNum == 1)
DIndividMain <- subset(DIndivid, select = c(Age2016, AgeMarry, LengthEst, Gender, HusbAgeMarry, WifeAgeMarry))
describe.by(DIndividMain, group=DIndividMain$Gender)

     #Descriptives on marriages

     #This determines if both the husband and wife for that marriage were interviewed
     #and limits it to only the row with the husband's info (arbitrarily)
Divorce2 <- Divorce
DMarr <- sqldf("SELECT *, (SELECT COUNT(*) FROM Divorce2 WHERE Divorce2.MarriagePID=Divorce.MarriagePID) AS MarriageDup FROM Divorce")
DMarr <- sqldf("SELECT * FROM DMarr WHERE MarriageDup=1 OR (MarriageDup=2 AND Gender=1)")
DMarr$Source <- ifelse(DMarr$MarriageDup == 2, DMarr$Source <- "Both", 
                       ifelse(DMarr$Gender == 1, DMarr$Source <- "Male", DMarr$Source <- "Female"))


DMarrMain <- subset(DMarr, select = c(LengthEst, AgeMarry, MarrNum, Outcome))
describe.by(DMarrMain)
describe.by(DMarrMain,group=DMarrMain$Outcome)
describe.by(DMarrMain,group=DMarrMain$MarrNum)



     #Kaplan-Meier of Marriage Dissolution (not including death)
MarrSurv <- survfit(Surv(LengthEst, Div) ~ 1, data = DMarr)
summary(MarrSurv)
ggsurvplot(MarrSurv,
           pval = TRUE, conf.int = TRUE,
           risk.table = TRUE, # Add risk table
           risk.table.col = "strata", # Change risk table color by groups
           linetype = "strata", # Change line type by groups
           xlab="Years in Marriage",
           ylab="Proportion Intact",
           surv.median.line = "hv", # Specify median survival
           ggtheme = theme_bw(), # Change ggplot2 theme
           palette = c("#E7B800", "#2E9FDF"))






                          #PREDICTORS OF DIVORCE


     #This expands the dataset to person-period format
DivorceExp <- survSplit(DMarr, cut=seq(1,100,1), start="Start", end="LengthEst", event="Div", episode="Year")
DivorceExp$CalendarYear <- DivorceExp$Year + DivorceExp$MarrYrEst - 1


     #This adds the number of children born to the couple who are <18 and alive for each year of marriage
Divorce3 <- sqldf("SELECT DivorceExp.*, 
                    (SELECT COUNT(*) FROM Demog WHERE Demog.fatherid=DivorceExp.Name AND
                                                            Demog.YOB<=DivorceExp.CalendarYear AND
                                                            Demog.YOB-DivorceExp.CalendarYear>-18 AND
                                                            ~Demog.YOD<=DivorceExp.CalendarYear)
                    AS NumDependsFather,
                    (SELECT COUNT(*) FROM Demog WHERE Demog.motherid=DivorceExp.Name AND
                                                            Demog.YOB<=DivorceExp.CalendarYear AND
                                                            Demog.YOB-DivorceExp.CalendarYear>-18 AND
                                                            ~Demog.YOD<=DivorceExp.CalendarYear)
                    AS NumDependsMother
                  FROM DivorceExp")

Divorce3$NumDepends <- Divorce3$NumDependsFather + Divorce3$NumDependsMother
Divorce3$YearSq <- Divorce3$Year*Divorce3$Year



     #Sets up final databases for survival analysis. Uses only first 20 years of marriage as
     #no divorces occurred after that.
DivorceFinal <- sqldf("SELECT PID, SpousePID, MarriagePID, HusbPID, WifePID, Name, Gender, Source, YrBorn, AgeMarry, SpYrBornEst, SpAgeMarry, 
                              HusbAgeMarry, WifeAgeMarry, MarrNum, MarrYrEst, LengthEst, EndYear, Year, YearSq, 
                              NumDepends, Div, Death, Censored, Outcome, WhoWantedDiv
                       FROM Divorce3 WHERE SpAgeMarry>0 AND Year<21")

     #Adds husband and wife ages for each year.
DivorceFinal$HusbAgeOngoing <- DivorceFinal$HusbAgeMarry + DivorceFinal$Year
DivorceFinal$WifeAgeOngoing <- DivorceFinal$WifeAgeMarry + DivorceFinal$Year



     #DISCRETE TIME EVENT HISTORY ANALYSIS OF LIKELIHOOD OF DIVORCE

     #Discrete event history analysis of likelihood of divorce with MarriageID as random effect
DivorceFinalModel <- brm ( Div ~ HusbAgeMarry + WifeAgeMarry + NumDepends + Year +  (1|MarriagePID),
                           data=DivorceFinal, family=binomial, iter=5000) 
summary(DivorceFinalModel)


     #Removing those less than 18 to see if effects still hold with just "adults".
DivorceFinalAdult <- sqldf("SELECT MarriagePID, PID, Name, Gender, Source, YrBorn, AgeMarry, SpousePID, SpYrBornEst, SpAgeMarry, 
                              HusbAgeMarry, WifeAgeMarry, MarrNum, MarrYrEst, LengthEst, EndYear, Year, YearSq, 
                              NumDepends, Div, Death, Censored, Outcome
                              FROM Divorce3 WHERE SpAgeMarry>0 AND Year<21 AND (HusbAgeMarry+Year-1)>17 AND (WifeAgeMarry+Year-1)>17")

DivorceFinalAdultModel <- brm ( Div ~ HusbAgeMarry + WifeAgeMarry + NumDepends + Year + (1|MarriagePID), data=DivorceFinalAdult,
                                  family=binomial, iter=5000) 
summary(DivorceFinalAdultModel)






                                            #INITIATORS OF DIVORCE


     #Sets up dataset using each divorce as unit of analysis to create crosstab
DivOnly <- subset(DMarr, DMarr$Div==1)
describe.by(DivOnly, group=DivOnly$WhoWantedDivorce)

CrossTable( DivOnly$WhoWantedDiv,DivOnly$Gender, expected=TRUE, prop.t=FALSE, 
            prop.c=FALSE, prop.chisq=TRUE, chisq=TRUE, fisher=TRUE )



     #Sets up dataset using each divorce as unit to determine factors influencing likelihood of wife wanting divorce more
DivorceWhoWants <- subset(DivorceFinal,DivorceFinal$Div==1)
DivorceWhoWants$WifeWant <- ifelse (DivorceWhoWants$WhoWantedDiv==0, DivorceWhoWants$WifeWant<-1, DivorceWhoWants$WifeWant<-0)
DivorceWhoWants$HusbWant <- ifelse (DivorceWhoWants$WhoWantedDiv==1, DivorceWhoWants$HusbWant<-1, DivorceWhoWants$HusbWant<-0)
DivorceWhoWants$WifeAgeDivorce <- DivorceWhoWants$WifeAgeMarry + DivorceWhoWants$LengthEst
DivorceWhoWants$HusbAgeDivorce <- DivorceWhoWants$HusbAgeMarry + DivorceWhoWants$LengthEst
CrossTable( DivorceWhoWants$WhoWantedDiv,DivorceWhoWants$NumDepends, expected=TRUE, prop.t=FALSE, 
            prop.c=TRUE, prop.chisq=TRUE, chisq=TRUE, fisher=TRUE )

     #Discrete event history analysis of likelihood of wife and husband wanting divorce with cross-random effects
DivorceWifeWantsModel <- brm (WifeWant ~ WifeAgeDivorce + NumDepends + (1|HusbPID) + (1|WifePID)
                            , data=DivorceWhoWants, family=bernoulli, iter=6000)

summary(DivorceWifeWantsModel)






                                 #COSTS OF DIVORCE


     #Sets up person-period format for periods after dissolution to explore which factors associated with likelihood of remarriage.

Divorce4 <- Divorce2

     #Calculates how many additional marriages exist
AfterDivorce <- sqldf("SELECT Divorce4.*, 
                      (SELECT COUNT(*) FROM Divorce2 WHERE Divorce2.PID=Divorce4.PID AND
                                                           Divorce2.MarrNum>Divorce4.MarrNum)
                      AS FurtherMarriages
                      FROM Divorce2 Divorce4")

     #Selects relevant variables
AfterDivorce <- sqldf("SELECT MarriagePID, PID, Name, Gender, YrBorn, AgeMarry, SpousePID, SpYrBornEst, SpAgeMarry, WhoWantedDiv,
                              HusbAgeMarry, WifeAgeMarry, MarrNum, MarrYrEst, LengthEst, EndYear, Div, FurtherMarriages
                       FROM AfterDivorce")

     #Gets the year of the next marriage
AfterDivorce$MarrNumNext <- AfterDivorce$MarrNum + 1
AfterDivorce2 <- AfterDivorce
AfterDivorce3 <- sqldf("SELECT AfterDivorce.*, (SELECT MarrYrEst FROM AfterDivorce2 WHERE PID=AfterDivorce.PID
                                                                 AND MarrNum=AfterDivorce.MarrNumNext)
                                                AS NextMarrYr FROM AfterDivorce2 AfterDivorce")

     #Sets up "Remarry" variable and calculates TimeSingle
AfterDivorce3 <- subset(AfterDivorce3, Div==1)
AfterDivorce3$Remarry <- ifelse(AfterDivorce3$FurtherMarriages>0, AfterDivorce3$Remarry <- 1, AfterDivorce3$Remarry <- 0)
AfterDivorce3$TimeSingle <- ifelse(AfterDivorce3$Remarry==0, AfterDivorce3$TimeSingle<-2016-AfterDivorce3$EndYear+1,
                                   ifelse(AfterDivorce3$NextMarrYr-AfterDivorce3$EndYear+1<1,1, AfterDivorce3$NextMarrYr-AfterDivorce3$EndYear+1))


     #Sets up person-period format for time between marriages to explore impacts of different factors on likelihood of remarriage

     #Person period format
AfterDivorce3$Start <- 0
AfterDivorce4 <- survSplit(AfterDivorce3, cut=seq(1,100,1), start="Start", end="TimeSingle", event="Remarry", episode="Year")
AfterDivorce4$CalendarYear <- AfterDivorce4$EndYear + AfterDivorce4$Year - 1

     #Calculate number dependents through time (different than above b/c kids can age out while single)
AfterDivorce5 <- sqldf("SELECT AfterDivorce4.*, 
                    (SELECT COUNT(*) FROM Demog WHERE Demog.fatherid=AfterDivorce4.Name AND
                                                            Demog.YOB<=AfterDivorce4.CalendarYear AND
                                                            Demog.YOB-AfterDivorce4.CalendarYear>-18 AND
                                                            ~Demog.YOD<=AfterDivorce4.CalendarYear)
                    AS NumDependsFather,
                    (SELECT COUNT(*) FROM Demog WHERE Demog.motherid=AfterDivorce4.Name AND
                                                            Demog.YOB<=AfterDivorce4.CalendarYear AND
                                                            Demog.YOB-AfterDivorce4.CalendarYear>-18 AND
                                                            ~Demog.YOD<=AfterDivorce4.CalendarYear)
                    AS NumDependsMother
                  FROM AfterDivorce4")

AfterDivorce5$NumDepends <- AfterDivorce5$NumDependsMother + AfterDivorce5$NumDependsFather

     #Calculate ego age, set up variable OtherWanted
AfterDivorce5$Age <- AfterDivorce5$CalendarYear - AfterDivorce5$YrBorn
AfterDivorce5$OtherWanted <- ifelse(AfterDivorce5$WhoWantedDiv==AfterDivorce5$Gender | AfterDivorce5$WhoWantedDiv==2,
                                    AfterDivorce5$OtherWanted <- 0, AfterDivorce5$OtherWanted <- 1)

AfterDivorceWomen <- subset(AfterDivorce5,Gender==0)
AfterDivorceMen <- subset(AfterDivorce5,Gender==1)


     #Discrete time event history analysis with ID as random both genders.
AfterDivorce5Model <- brm ( Remarry ~ Gender + Age + NumDepends + OtherWanted +  (1|PID), 
                            data=AfterDivorce5, family=bernoulli, iter=6000) 
summary(AfterDivorce5Model)


    #With interaction terms
AfterDivorce5Model <- brm ( Remarry ~ Gender + Age + NumDepends + OtherWanted + Gender*Age + Gender*NumDepends + (1|PID), 
                            data=AfterDivorce5, family=bernoulli, iter=6000) 
summary(AfterDivorce5Model)

CrossTable( DivorceFinal$Year,DivorceFinal$NumDepends, expected=FALSE, prop.t=FALSE, 
            prop.c=FALSE, prop.chisq=FALSE, chisq=FALSE, fisher=FALSE )

describe.by(DivorceFinal, group=DivorceFinal$Year)
